@@ -1,34 +1,35 @@
-#' Custom Lattice Boxplot
-#' 
-#' This generates a custom lattice boxplot; we super-impose actual plot points
-#' for groups with a small number of points, and also restrict plotting of the
-#' boxplot for these as well (since they are really rather mis-representative
-#' of the distribution when there are so few points.) The downside is that
-#' functionality is not implemented for multi-panel plots.
-#' 
-#' Axis labels are inferred from the \code{form} object passed in when possible.
-#' 
-#' @param form a formula object as expected by \code{lattice}'s \code{xyplot}.
-#' @param data see \code{\link{xyplot}}.
-#' @param xlab see \code{\link{xyplot}}.
-#' @param ylab see \code{\link{xyplot}}.
-#' @param main see \code{\link{xyplot}}.
-#' @param n number of points necessary for a boxplot to be drawn.
-#' @param ... additional arguments passed to \code{xyplot} call.
-#' @export
-#' @examples
-#' set.seed(123)
-#' dat <- data.frame( y=rnorm(100), x=factor( rbinom(100,size=2,p=0.8) ) )
-#' bwplot2( x ~ y , dat)
+##' Custom Lattice Boxplot
+##' 
+##' This generates a custom lattice boxplot; we super-impose actual plot points
+##' for groups with a small number of points, and also restrict plotting of the
+##' boxplot for these as well (since they are really rather mis-representative
+##' of the distribution when there are so few points.) The downside is that
+##' functionality is not implemented for multi-panel plots.
+##' 
+##' Axis labels are inferred from the \code{form} object passed in when possible.
+##' 
+##' @importFrom lattice stripplot panel.abline panel.bwplot panel.stripplot
+##' @param form a formula object as expected by \code{lattice}'s \code{xyplot}.
+##' @param data see \code{\link{xyplot}}.
+##' @param xlab see \code{\link{xyplot}}.
+##' @param ylab see \code{\link{xyplot}}.
+##' @param main see \code{\link{xyplot}}.
+##' @param n number of points necessary for a boxplot to be drawn.
+##' @param ... additional arguments passed to \code{xyplot} call.
+##' @export
+##' @examples
+##' set.seed(123)
+##' dat <- data.frame( y=rnorm(100), x=factor( rbinom(100,size=2,p=0.8) ) )
+##' bwplot2( x ~ y , dat)
 bwplot2 <- function( form, 
                      data=NULL, 
-                     xlab = NULL, 
-                     ylab = NULL, 
+                     xlab=NULL, 
+                     ylab=NULL, 
                      main=NULL, 
                      n=10, 
                      ... ) {
   
-  if( re.exists( "\\|", attr( terms(form), "variable" ) ) ) {
+  if( re_exists(attr( terms(form), "variable" ), "\\|") ) {
     stop("not implemented for multi-panel plots")
   }
   
@@ -43,19 +44,21 @@ bwplot2 <- function( form,
     ylab <- gsub( ".*\\$", "", terms[1] )
   }
   
-  if( is.null(data) ) {
-    data <- gsub( "\\$.*", "", terms[1] )
-    data <- get(data)
-  }
-  
   xterm <- gsub( ".*\\$", "", terms[2] )
   yterm <- gsub( ".*\\$", "", terms[1] )
   zterm <- gsub( ".*\\$", "", terms[3] )
   
-  tDat <- data.frame(
-    y = data[[yterm]],
-    x = data[[xterm]]
-  )
+  if( is.null(data) ) {
+    tDat <- data.frame(
+      y = eval( form[[2]] ),
+      x = eval( form[[3]] )
+    )
+  } else {
+    tDat <- data.frame(
+      y = data[[yterm]],
+      x = data[[xterm]]
+    )
+  }
   
   if( !is.na(zterm) ) tDat$z <- data[[zterm]]
   
@@ -80,7 +83,7 @@ bwplot2 <- function( form,
              panel = function(x, y, ...) {
                
                
-               for( i in 1:lu(y) ) {
+               for (i in 1:length( unique(y) )) {
                  panel.abline( h = i, col='grey')
                }
                
@@ -94,7 +97,6 @@ bwplot2 <- function( form,
                panel.bwplot(bDat$x, bDat$y, fill="lavender", pch = "|", ...)
                
                ## plot only the values for which we have <n points
-               
                cDat$x[ cDat$num > n ] <- NA
                
                panel.stripplot(cDat$x, cDat$y, 
