@@ -1,13 +1,13 @@
-#' Clean Documentation in Current Package
-#' 
-#' This function removes all the .Rd documentation files present in
-#' \code{<dir>/man}. This function is handy if you've 'polluted' your
-#' manual directory in prototyping different functions -- assuming that
-#' you're documenting your code with eg. \code{roxygen}.
-#' 
-#' @param dir the project directory.
-#' @param ask boolean. ask before clearing directory?
-#' @export
+##' Clean Documentation in Current Package
+##' 
+##' This function removes all the .Rd documentation files present in
+##' \code{<dir>/man}. This function is handy if you've 'polluted' your
+##' \code{man} directory in prototyping different functions -- assuming that
+##' you're documenting your code with eg. \code{roxygen}.
+##' 
+##' @param dir the project directory.
+##' @param ask boolean. ask before clearing directory?
+##' @export
 clean_doc <- function(dir=getwd(), ask=TRUE) {
   
   man_dir <- file.path( dir, "man" )
@@ -17,7 +17,7 @@ clean_doc <- function(dir=getwd(), ask=TRUE) {
   }
   if( ask ) {
     cat("Are you sure you want to delete all the files in:\n\t", man_dir, "? (y/n):\n")
-    if( re.exists( "^y", scan(what=character(), n=1, quiet=TRUE) ) ) {
+    if( re_exists( "^y", scan(what=character(), n=1, quiet=TRUE) ) ) {
       for( file in files ) file.remove(file)
       cat("Documentation files deleted.\n")
     } else {
